schemarender

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 28, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package schemarender converts schema.Schema values to map[string]any objects suitable for marshalling into OpenAPI or AsyncAPI documents.

Both render/openapi and render/asyncapi delegate to this package so that adding a new schema field requires only one change.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SchemaObject

func SchemaObject(s schema.Schema) map[string]any

SchemaObject converts s into a JSON-schema-compatible map[string]any. Only fields that are set in s are included in the output.

Types

This section is empty.

Jump to